# printm

printm is an open-source Python package providing CUI output like more/less command in Python script.

![](https://raw.githubusercontent.com/tatsuya4649/printm/master/docs/assets/printm.gif)

## Feature

* simple: you can use like `print`.

* freedom: you can change placeholder and blank, etc.

## Install

``` 
$ pip install printm 
```

## Usage

```python
from printm import printm

printm(
    output="your output string",
    placeholder="placeholder string",
)
```

## LICENCE

printm is licensed under the terms of MIT license.
